@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "magit-tbdiff" "1.2.0"
+(define-package "magit-tbdiff" "20250915.2109"
   "Magit extension for range diffs."
   '((emacs "26.1")
     (magit "4.0.0"))
   :url "https://github.com/magit/magit-tbdiff"
-  :commit "e8219d2db176bfccb1aa485c9ae91743c33ada0e"
-  :revdesc "v1.2.0-0-ge8219d2db176"
+  :commit "f77cffb98dae726f011b133db8936df9ac4a657a"
+  :revdesc "f77cffb98dae"
   :keywords '("vc" "tools")
   :authors '(("Kyle Meyer" . "kyle@kyleam.com"))
   :maintainers '(("Kyle Meyer" . "kyle@kyleam.com")))
